@@ -7,9 +7,11 @@ import logging
 from logging import handlers
 from functools import wraps
 from textwrap import shorten
+from datetime import datetime
 
 DATEFORMAT_STD = "%Y-%m-%d %H:%M:%S"
 DATEFORMAT_DEV = "%H:%M:%S"
+DATEFORMAT_FILE = "%Y-%m-%d_%H-%M-%S"
 
 
 def pathmaker(first_segment, *in_path_segments, rev=False):
@@ -61,6 +63,8 @@ def NEWRUN():
 
 
 def class_init_notification(logger, in_class, use=None):
+    if os.getenv('DISABLE_INITIATION_LOG_CALLS') == "1":
+        return
     if use == 'repr':
         _string = f"'{repr(in_class)}'"
     elif use == 'str':
@@ -84,6 +88,13 @@ def aux_logger(in_name):
     return logging.getLogger('main.' + in_name)
 
 
+def library_base_logger(library_name: str):
+    return logging.getLogger(library_name).addHandler(logging.NullHandler())
+
+
+def aux_library_logger(in_name: str):
+    return logging.getLogger(__name__)
+
 # def main_logger(in_file_name, in_level, in_back_up=2):
 
 #     _out = logging.getLogger('main')
@@ -99,6 +110,7 @@ def aux_logger(in_name):
 
 #     return _out
 
+
 class CustomFormatter(logging.Formatter):
     """ Custom Formatter does these 2 things:
     1. Overrides 'funcName' with the value of 'func_name_override', if it exists.
@@ -143,6 +155,7 @@ def _stdout_handler():
 
 def main_logger(in_file_name, in_level='DEBUG', in_back_up=2, other_logger_names=None, log_to='both'):
     log_to = log_to.casefold()
+    should_roll_over = os.path.isfile(in_file_name)
     run_rotating_file_handler = _each_run_file_rotate_handler(in_file_name=in_file_name, in_back_up=in_back_up)
     stdout_handler = _stdout_handler()
     _out = logging.getLogger('main')
@@ -154,7 +167,7 @@ def main_logger(in_file_name, in_level='DEBUG', in_back_up=2, other_logger_names
         if log_to in ['both', 'stdout']:
             logger.addHandler(stdout_handler)
     if log_to in ['both', 'file']:
-        should_roll_over = os.path.isfile(in_file_name)
+
         if should_roll_over:
             run_rotating_file_handler.doRollover()
     return _out
@@ -192,6 +205,26 @@ def std_namer(name):
     return new_path
 
 
+def timestamp_log_folderer(in_log_file_name, in_main_log_folder=None):
+    if in_main_log_folder is None:
+        _cwd = pathmaker(os.getcwd(), 'logs')
+    elif isinstance(in_main_log_folder, str):
+        if os.path.basename(in_main_log_folder) == 'logs':
+            _cwd = pathmaker(in_main_log_folder)
+        else:
+            _cwd = pathmaker(in_main_log_folder, 'logs')
+
+    elif _is_appdata_object(in_main_log_folder) is True:
+        _cwd = pathmaker(in_main_log_folder.log_folder)
+
+    else:
+        raise TypeError(f"type {type(in_main_log_folder)} not supported")
+    _path_to_old_folder = pathmaker(_cwd, 'old_logs')
+    if os.path.exists(_path_to_old_folder) is False:
+        os.makedirs(_path_to_old_folder)
+    return pathmaker(_cwd, in_log_file_name + '_' + datetime.utcnow().strftime(DATEFORMAT_FILE) + ".log")
+
+
 def log_folderer(in_log_file_name, in_main_log_folder=None):
     if in_main_log_folder is None:
         _cwd = pathmaker(os.getcwd(), 'logs')
